@@ -112,18 +112,13 @@ def hk_gen(h):
       """k dependent hamiltonian, k goes from 0 to 1"""
       mout = h.intra.copy() # intracell term
       for t in hopping: # loop over matrices
-        try: kp = k[0]  # extract the first component
-        except: kp = k  # assume it is a float
-#        phi = t.dir[0]*kp # phase
         tk = t.m * h.geometry.bloch_phase(t.dir,k) # k hopping
-#        tk = t.m * np.exp(1j*np.pi*2.*phi) # k hopping
         mout = mout + tk 
       return mout
     return hk  # return the function
   elif h.dimensionality == 2: # two dimensional
     def hk(k):
       """k dependent hamiltonian, k goes from 0 to 1"""
-#      k = np.array([k[0],k[1]]) # convert to array
       mout = h.intra.copy() # intracell term
       for t in hopping: # loop over matrices
         tk = t.m * h.geometry.bloch_phase(t.dir,k) # k hopping
@@ -256,7 +251,8 @@ def clean(h,cutoff=0.0001):
 
 
 
-def supercell_hamiltonian(hin,nsuper=[1,1,1],sparse=True,ncut=3):
+def supercell_hamiltonian(hin,nsuper=[1,1,1],sparse=True,ncut=3,
+                             **kwargs):
   """ Create a ribbon hamiltonian object"""
 #  raise # there is something wrong with this function
 #  print("This function might have something wrong")
@@ -265,7 +261,7 @@ def supercell_hamiltonian(hin,nsuper=[1,1,1],sparse=True,ncut=3):
   hr = h.copy() # copy hamiltonian
   if sparse: hr.is_sparse = True # sparse output
   # stuff about geometry
-  hr.geometry = h.geometry.supercell(nsuper) # create supercell
+  hr.geometry = h.geometry.get_supercell(nsuper,**kwargs) # create supercell
   n = nsuper[0]*nsuper[1]*nsuper[2] # number of cells in the supercell
   pos = [] # positions inside the supercell
   for i in range(nsuper[0]):
