@@ -4,6 +4,7 @@ import numpy as np
 
 def get_operator(self,name,**kwargs):
       """Return the conventional operator"""
+      if type(name) is operators.Operator: return name # return operator
       if name=="None": return None
       elif name in ["berry","Berry"]: 
           return operators.get_berry(self,**kwargs)
@@ -31,6 +32,9 @@ def get_operator(self,name,**kwargs):
       elif name=="deltaz": return operators.get_pairing(self,ptype="deltaz")
       elif name=="electron": return operators.get_electron(self)
       elif name=="hole": return operators.get_hole(self)
+      elif name=="mass": 
+          from .mass import mass_operator
+          return mass_operator(self,**kwargs)
       elif name in ["up"]: return operators.get_up(self)
       elif name in ["dn","down"]: return operators.get_dn(self)
       elif name=="zposition": return operators.get_zposition(self)
@@ -62,6 +66,9 @@ def get_operator(self,name,**kwargs):
         return operators.get_valley_layer(self,n=0)
       elif name in ["ipr","IPR"]: return operators.ipr
       elif name=="potential":  return operators.get_potential(self,**kwargs)
+      elif name=="unfold":  
+          from .unfolding import bloch_projector
+          return bloch_projector(self,**kwargs)
       else: raise
 
 
