@@ -90,7 +90,7 @@ def commensurate_potential(g,k=1,amplitude=1.0,n=None,
         else: n = 3
       f = cnpot(n=n,k=g.b1,**kwargs)
     elif g.dimensionality==1: 
-        raise # not implemented
+      f = cnpot(n=1,k=k*g.b1,**kwargs)
     else: raise
     f = enforce_amplitude(f,amplitude,g=g) # enforce the amplitude
     f = enforce_average(f,average,g=g) # enforce average
@@ -215,3 +215,15 @@ def object2potential(V,r=None):
 
 
 from .potentialtk.profiles import radial_decay
+
+
+def delta(r0,v0=1.0):
+    """Delta function potential"""
+    def f(r):
+        dr = r - r0
+        dr2 = dr.dot(dr)
+        if dr2<1e-4: return v0
+        else: return v0*0.0
+    return Potential(f) # return potential
+
+
